@@ -646,7 +646,7 @@ my $standup_liferay=sub {
    if (exists $main::aws->{'Liferay.com'}) {
       my $g=get_aws_security_id('LiferaySecurityGroup');
       my $c="aws ec2 run-instances --image-id $i --count 1 ".
-            "--instance-type $type --key-name $pemfile ".
+            "--instance-type $type --key-name \'$pemfile\' ".
             "--security-group-ids $g --subnet-id $s";
       if ($#{$main::aws->{'Liferay.com'}}==0) {
          launch_server('Liferay.com',$cnt,$liferay,'',$c,
@@ -663,7 +663,7 @@ my $standup_liferay=sub {
    if (exists $main::aws->{'Apache.org'}) {
       my $g=get_aws_security_id('ApacheSecurityGroup');
       my $c="aws ec2 run-instances --image-id $i --count 1 ".
-         "--instance-type $type --key-name $pemfile ".
+         "--instance-type $type --key-name \'$pemfile\' ".
          "--security-group-ids $g --subnet-id $s";
       if ($#{$main::aws->{'Apache.org'}}==0) {
          launch_server('Apache.org',$cnt,'','',$c,
@@ -680,7 +680,7 @@ my $standup_liferay=sub {
    if (exists $main::aws->{'MySQL.com'}) {
       my $g=get_aws_security_id('MySQLSecurityGroup');
       my $c="aws ec2 run-instances --image-id $i --count 1 ".
-         "--instance-type $type --key-name $pemfile ".
+         "--instance-type $type --key-name \'$pemfile\' ".
          "--security-group-ids $g --subnet-id $s";
       if ($#{$main::aws->{'MySQL.com'}}==0) {
          launch_server('MySQL.com',$cnt,$database,'',$c,
